from zope.interface import Interface


class IMorph(Interface):
    """
    morph interface
    """


class IMorphset(Interface):
    """
    morpheme interface
    """


class IMeaning(Interface):
    """
    meaning interface
    """


class IWordform(Interface):
    """
    form interface
    """


class IPOS(Interface):
    """
    part of speech interface
    """
